'''
Elemental Data and Radii

The element table contains: 

element name 
element symbol 
periodic table period number [6Lan for Lanthanoids, 7Act for Actinoids] 
periodic table group number [19 for Lanthanoids, 20 for Actinoids) 
periodic table block (s, p, d, f) 
atomic weight [IUPAC, 1997, see Note (a)] 
covalent radius of the element as used in CSD software [Å, see Note (b)] 
van der Waals radius of the element as used in CSD software [Å, see Note (c)] 

Notes 

(a) data given as [nnn] indicate the mass number of the longest lived isotope 

(b) CSD covalent radii (Rcov) are used to assign bonded connections in crystal structures. A bonded connection is established if the distance (d) between two elements A and B is in the range from Rcov(A) + Rcov(B) - t to Rcov(A) + Rcov(B) + t, where the tolerance (t) is usually set to 0.4 Å. The tolerance and Rcov values can be altered by CSD Editors to force bonds in certain situations. The Rcov values have been refined over the years to minimise the need for editorial changes for specific structures. Radii for metals are taken from S. Alvarez et al., Dalton Trans., 2008, 2832-2838 since the 2010 CSD release. Where there were radii defined for more than one metal oxidation state, the value for the most common of these has been chosen. Elements not yet encountered in the CSD have Rcov = 1.50 Å. 

(c) van der Waals radii are taken from A. Bondi, J. Phys. Chem., 68, 441-452, 1964, except the value for H, which is taken from R. S. Rowland & R. Taylor, J. Phys. Chem., 100, 7384 - 7391, 1996. Radii that are not available in either of these publications have RvdW = 2.00 Å. 

Links 

The Web contains many sites that provide data on the chemical elements. Links to many of these are provided at: http://www.chemistrycoach.com/periodic_tables.htm#PeriodicTables 

Two excellent relevant sites are:
        http://www.webelements.com/
        http://www.rsc.org/periodic-table/ 
'''

FULLNAME = {
            'Ac': 'Actinium',
            'Al': 'Aluminium',
            'Am': 'Americium',
            'Sb': 'Antimony',
            'Ar': 'Argon',
            'As': 'Arsenic',
            'At': 'Astatine',
            'Ba': 'Barium',
            'Bk': 'Berkelium',
            'Be': 'Beryllium',
            'Bi': 'Bismuth',
            'Bh': 'Bohrium',
            'B': 'Boron',
            'Br': 'Bromine',
            'Cd': 'Cadmium',
            'Cs': 'Caesium',
            'Ca': 'Calcium',
            'Cf': 'Californium',
            'C': 'Carbon',
            'Ce': 'Cerium',
            'Cl': 'Chlorine',
            'Cr': 'Chromium',
            'Co': 'Cobalt',
            'Cu': 'Copper',
            'Cm': 'Curium',
            'Ds': 'Darmstadtium',
            'Db': 'Dubnium',
            'Dy': 'Dysprosium',
            'Es': 'Einsteinium',
            'Er': 'Erbium',
            'Eu': 'Europium',
            'Fm': 'Fermium',
            'F': 'Fluorine',
            'Fr': 'Francium',
            'Gd': 'Gadolinium',
            'Ga': 'Gallium',
            'Ge': 'Germanium',
            'Au': 'Gold',
            'Hf': 'Hafnium',
            'Hs': 'Hassium',
            'He': 'Helium',
            'Ho': 'Holmium',
            'H': 'Hydrogen',
            'In': 'Indium',
            'I': 'Iodine',
            'Ir': 'Iridium',
            'Fe': 'Iron',
            'Kr': 'Krypton',
            'La': 'Lanthanum',
            'Lr': 'Lawrencium',
            'Pb': 'Lead',
            'Li': 'Lithium',
            'Lu': 'Lutetium',
            'Mg': 'Magnesium',
            'Mn': 'Manganese',
            'Mt': 'Meitnerium',
            'Md': 'Mendelevium',
            'Hg': 'Mercury',
            'Mo': 'Molybdenum',
            'Nd': 'Neodymium',
            'Ne': 'Neon',
            'Np': 'Neptunium',
            'Ni': 'Nickel',
            'Nb': 'Niobium',
            'N': 'Nitrogen',
            'No': 'Nobelium',
            'Os': 'Osmium',
            'O': 'Oxygen',
            'Pd': 'Palladium',
            'P': 'Phosphorus',
            'Pt': 'Platinum',
            'Pu': 'Plutonium',
            'Po': 'Polonium',
            'K': 'Potassium',
            'Pr': 'Praseodymium',
            'Pm': 'Promethium',
            'Pa': 'Protactinium',
            'Ra': 'Radium',
            'Rn': 'Radon',
            'Re': 'Rhenium',
            'Rh': 'Rhodium',
            'Rb': 'Rubidium',
            'Ru': 'Ruthenium',
            'Rf': 'Rutherfordium',
            'Sm': 'Samarium',
            'Sc': 'Scandium',
            'Sg': 'Seaborgium',
            'Se': 'Selenium',
            'Si': 'Silicon',
            'Ag': 'Silver',
            'Na': 'Sodium',
            'Sr': 'Strontium',
            'S': 'Sulphur',
            'Ta': 'Tantalum',
            'Tc': 'Technetium',
            'Te': 'Tellurium',
            'Tb': 'Terbium',
            'Tl': 'Thallium',
            'Th': 'Thorium',
            'Tm': 'Thulium',
            'Sn': 'Tin',
            'Ti': 'Titanium',
            'W': 'Tungsten',
            'U': 'Uranium',
            'V': 'Vanadium',
            'Xe': 'Xenon',
            'Yb': 'Ytterbium',
            'Y': 'Yttrium',
            'Zn': 'Zinc',
            'Zr': 'Zirconium'
            }

PERIOD = {
            'Ac': '7Act',
            'Al': '3',
            'Am': '7Act',
            'Sb': '5',
            'Ar': '3',
            'As': '4',
            'At': '6',
            'Ba': '6',
            'Bk': '7Act',
            'Be': '2',
            'Bi': '6',
            'Bh': '7',
            'B': '2',
            'Br': '4',
            'Cd': '5',
            'Cs': '6',
            'Ca': '4',
            'Cf': '7Act',
            'C': '2',
            'Ce': '6Lan',
            'Cl': '3',
            'Cr': '4',
            'Co': '4',
            'Cu': '4',
            'Cm': '7Act',
            'Ds': '7',
            'Db': '7',
            'Dy': '6Lan',
            'Es': '7Act',
            'Er': '6Lan',
            'Eu': '6Lan',
            'Fm': '7Act',
            'F': '2',
            'Fr': '7',
            'Gd': '6Lan',
            'Ga': '4',
            'Ge': '4',
            'Au': '6',
            'Hf': '6',
            'Hs': '7',
            'He': '1',
            'Ho': '6Lan',
            'H': '1',
            'In': '5',
            'I': '5',
            'Ir': '6',
            'Fe': '4',
            'Kr': '4',
            'La': '6Lan',
            'Lr': '7',
            'Pb': '6',
            'Li': '2',
            'Lu': '6',
            'Mg': '3',
            'Mn': '4',
            'Mt': '7',
            'Md': '7Act',
            'Hg': '6',
            'Mo': '5',
            'Nd': '6Lan',
            'Ne': '2',
            'Np': '7Act',
            'Ni': '4',
            'Nb': '5',
            'N': '2',
            'No': '7Act',
            'Os': '6',
            'O': '2',
            'Pd': '5',
            'P': '3',
            'Pt': '6',
            'Pu': '7Act',
            'Po': '6',
            'K': '4',
            'Pr': '6Lan',
            'Pm': '6Lan',
            'Pa': '7Act',
            'Ra': '7',
            'Rn': '6',
            'Re': '6',
            'Rh': '5',
            'Rb': '5',
            'Ru': '5',
            'Rf': '7',
            'Sm': '6Lan',
            'Sc': '4',
            'Sg': '7',
            'Se': '4',
            'Si': '3',
            'Ag': '5',
            'Na': '3',
            'Sr': '5',
            'S': '3',
            'Ta': '6',
            'Tc': '5',
            'Te': '5',
            'Tb': '6Lan',
            'Tl': '6',
            'Th': '7Act',
            'Tm': '6Lan',
            'Sn': '5',
            'Ti': '4',
            'W': '6',
            'U': '7Act',
            'V': '4',
            'Xe': '5',
            'Yb': '6Lan',
            'Y': '5',
            'Zn': '4',
            'Zr': '5'
            }

GROUP = {
            'Ac': 20,
            'Al': 13,
            'Am': 20,
            'Sb': 15,
            'Ar': 18,
            'As': 15,
            'At': 17,
            'Ba': 2,
            'Bk': 20,
            'Be': 2,
            'Bi': 15,
            'Bh': 7,
            'B': 13,
            'Br': 17,
            'Cd': 12,
            'Cs': 1,
            'Ca': 2,
            'Cf': 20,
            'C': 14,
            'Ce': 19,
            'Cl': 17,
            'Cr': 6,
            'Co': 9,
            'Cu': 11,
            'Cm': 20,
            'Ds': 10,
            'Db': 5,
            'Dy': 19,
            'Es': 20,
            'Er': 19,
            'Eu': 19,
            'Fm': 20,
            'F': 17,
            'Fr': 1,
            'Gd': 19,
            'Ga': 13,
            'Ge': 14,
            'Au': 11,
            'Hf': 4,
            'Hs': 8,
            'He': 18,
            'Ho': 19,
            'H': 1,
            'In': 13,
            'I': 17,
            'Ir': 9,
            'Fe': 8,
            'Kr': 18,
            'La': 19,
            'Lr': 3,
            'Pb': 14,
            'Li': 1,
            'Lu': 3,
            'Mg': 2,
            'Mn': 7,
            'Mt': 9,
            'Md': 20,
            'Hg': 12,
            'Mo': 6,
            'Nd': 19,
            'Ne': 18,
            'Np': 20,
            'Ni': 10,
            'Nb': 5,
            'N': 15,
            'No': 20,
            'Os': 8,
            'O': 16,
            'Pd': 10,
            'P': 15,
            'Pt': 10,
            'Pu': 20,
            'Po': 16,
            'K': 1,
            'Pr': 19,
            'Pm': 19,
            'Pa': 20,
            'Ra': 2,
            'Rn': 18,
            'Re': 7,
            'Rh': 9,
            'Rb': 1,
            'Ru': 8,
            'Rf': 4,
            'Sm': 19,
            'Sc': 3,
            'Sg': 6,
            'Se': 16,
            'Si': 14,
            'Ag': 11,
            'Na': 1,
            'Sr': 2,
            'S': 16,
            'Ta': 5,
            'Tc': 7,
            'Te': 16,
            'Tb': 19,
            'Tl': 13,
            'Th': 20,
            'Tm': 19,
            'Sn': 14,
            'Ti': 4,
            'W': 6,
            'U': 20,
            'V': 5,
            'Xe': 18,
            'Yb': 19,
            'Y': 3,
            'Zn': 12,
            'Zr': 4
            }

BLOCK = {
            'Ac': 'f',
            'Al': 'p',
            'Am': 'f',
            'Sb': 'p',
            'Ar': 'p',
            'As': 'p',
            'At': 'p',
            'Ba': 's',
            'Bk': 'f',
            'Be': 's',
            'Bi': 'p',
            'Bh': 'd',
            'B': 'p',
            'Br': 'p',
            'Cd': 'd',
            'Cs': 's',
            'Ca': 's',
            'Cf': 'f',
            'C': 'p',
            'Ce': 'f',
            'Cl': 'p',
            'Cr': 'd',
            'Co': 'd',
            'Cu': 'd',
            'Cm': 'f',
            'Ds': 'd',
            'Db': 'd',
            'Dy': 'f',
            'Es': 'f',
            'Er': 'f',
            'Eu': 'f',
            'Fm': 'f',
            'F': 'p',
            'Fr': 's',
            'Gd': 'f',
            'Ga': 'p',
            'Ge': 'p',
            'Au': 'd',
            'Hf': 'd',
            'Hs': 'd',
            'He': 'p',
            'Ho': 'f',
            'H': 's',
            'In': 'p',
            'I': 'p',
            'Ir': 'd',
            'Fe': 'd',
            'Kr': 'p',
            'La': 'f',
            'Lr': 'd',
            'Pb': 'p',
            'Li': 's',
            'Lu': 'd',
            'Mg': 's',
            'Mn': 'd',
            'Mt': 'd',
            'Md': 'f',
            'Hg': 'd',
            'Mo': 'd',
            'Nd': 'f',
            'Ne': 'p',
            'Np': 'f',
            'Ni': 'd',
            'Nb': 'd',
            'N': 'p',
            'No': 'f',
            'Os': 'd',
            'O': 'p',
            'Pd': 'd',
            'P': 'p',
            'Pt': 'd',
            'Pu': 'f',
            'Po': 'p',
            'K': 's',
            'Pr': 'f',
            'Pm': 'f',
            'Pa': 'f',
            'Ra': 's',
            'Rn': 'p',
            'Re': 'd',
            'Rh': 'd',
            'Rb': 's',
            'Ru': 'd',
            'Rf': 'd',
            'Sm': 'f',
            'Sc': 'd',
            'Sg': 'd',
            'Se': 'p',
            'Si': 'p',
            'Ag': 'd',
            'Na': 's',
            'Sr': 's',
            'S': 'p',
            'Ta': 'd',
            'Tc': 'd',
            'Te': 'p',
            'Tb': 'f',
            'Tl': 'p',
            'Th': 'f',
            'Tm': 'f',
            'Sn': 'p',
            'Ti': 'd',
            'W': 'd',
            'U': 'f',
            'V': 'd',
            'Xe': 'p',
            'Yb': 'f',
            'Y': 'd',
            'Zn': 'd',
            'Zr': 'd'
            }

ATOMICNUMBER = {
                'Ac': 89,
                'Al': 13,
                'Am': 95,
                'Sb': 51,
                'Ar': 18,
                'As': 33,
                'At': 85,
                'Ba': 56,
                'Bk': 97,
                'Be': 4,
                'Bi': 83,
                'Bh': 107,
                'B': 5,
                'Br': 35,
                'Cd': 48,
                'Cs': 55,
                'Ca': 20,
                'Cf': 98,
                'C': 6,
                'Ce': 58,
                'Cl': 17,
                'Cr': 24,
                'Co': 27,
                'Cu': 29,
                'Cm': 96,
                'Ds': 110,
                'Db': 105,
                'Dy': 66,
                'Es': 99,
                'Er': 68,
                'Eu': 63,
                'Fm': 100,
                'F': 9,
                'Fr': 87,
                'Gd': 64,
                'Ga': 31,
                'Ge': 32,
                'Au': 79,
                'Hf': 72,
                'Hs': 108,
                'He': 2,
                'Ho': 67,
                'H': 1,
                'In': 49,
                'I': 53,
                'Ir': 77,
                'Fe': 26,
                'Kr': 36,
                'La': 57,
                'Lr': 103,
                'Pb': 82,
                'Li': 3,
                'Lu': 71,
                'Mg': 12,
                'Mn': 25,
                'Mt': 109,
                'Md': 101,
                'Hg': 80,
                'Mo': 42,
                'Nd': 60,
                'Ne': 10,
                'Np': 93,
                'Ni': 28,
                'Nb': 41,
                'N': 7,
                'No': 102,
                'Os': 76,
                'O': 8,
                'Pd': 46,
                'P': 15,
                'Pt': 78,
                'Pu': 94,
                'Po': 84,
                'K': 19,
                'Pr': 59,
                'Pm': 61,
                'Pa': 91,
                'Ra': 88,
                'Rn': 86,
                'Re': 75,
                'Rh': 45,
                'Rb': 37,
                'Ru': 44,
                'Rf': 104,
                'Sm': 62,
                'Sc': 21,
                'Sg': 106,
                'Se': 34,
                'Si': 14,
                'Ag': 47,
                'Na': 11,
                'Sr': 38,
                'S': 16,
                'Ta': 73,
                'Tc': 43,
                'Te': 52,
                'Tb': 65,
                'Tl': 81,
                'Th': 90,
                'Tm': 69,
                'Sn': 50,
                'Ti': 22,
                'W': 74,
                'U': 92,
                'V': 23,
                'Xe': 54,
                'Yb': 70,
                'Y': 39,
                'Zn': 30,
                'Zr': 40
                }


ATOMICWEIGHT = {
                'Ac': 227,
                'Al': 26,
                'Am': 243,
                'Sb': 121,
                'Ar': 39,
                'As': 74,
                'At': 210,
                'Ba': 137,
                'Bk': 247,
                'Be': 9,
                'Bi': 208,
                'Bh': 264,
                'B': 10,
                'Br': 79,
                'Cd': 112,
                'Cs': 132,
                'Ca': 40,
                'Cf': 251,
                'C': 12,
                'Ce': 140,
                'Cl': 35,
                'Cr': 51,
                'Co': 58,
                'Cu': 63,
                'Cm': 247,
                'Ds': 271,
                'Db': 262,
                'Dy': 162,
                'Es': 252,
                'Er': 167,
                'Eu': 151,
                'Fm': 257,
                'F': 18,
                'Fr': 223,
                'Gd': 157,
                'Ga': 69,
                'Ge': 72,
                'Au': 196,
                'Hf': 178,
                'Hs': 269,
                'He': 4,
                'Ho': 164,
                'H': 1,
                'In': 114,
                'I': 126,
                'Ir': 192,
                'Fe': 55,
                'Kr': 83,
                'La': 138,
                'Lr': 262,
                'Pb': 207,
                'Li': 6,
                'Lu': 174,
                'Mg': 24,
                'Mn': 54,
                'Mt': 268,
                'Md': 258,
                'Hg': 200,
                'Mo': 95,
                'Nd': 144,
                'Ne': 20,
                'Np': 237,
                'Ni': 58,
                'Nb': 92,
                'N': 14,
                'No': 259,
                'Os': 190,
                'O': 15,
                'Pd': 106,
                'P': 30,
                'Pt': 195,
                'Pu': 244,
                'Po': 210,
                'K': 39,
                'Pr': 140,
                'Pm': 145,
                'Pa': 231,
                'Ra': 226,
                'Rn': 222,
                'Re': 186,
                'Rh': 102,
                'Rb': 85,
                'Ru': 101,
                'Rf': 261,
                'Sm': 150,
                'Sc': 44,
                'Sg': 266,
                'Se': 78,
                'Si': 28,
                'Ag': 107,
                'Na': 22,
                'Sr': 87,
                'S': 32,
                'Ta': 180,
                'Tc': 98,
                'Te': 127,
                'Tb': 158,
                'Tl': 204,
                'Th': 232,
                'Tm': 168,
                'Sn': 118,
                'Ti': 47,
                'W': 183,
                'U': 238,
                'V': 50,
                'Xe': 131,
                'Yb': 173,
                'Y': 88,
                'Zn': 65,
                'Zr': 91
}
COVALENTRADII = {
                'Ac': 2.15,
                'Al': 1.21,
                'Am': 1.8,
                'Sb': 1.39,
                'Ar': 1.51,
                'As': 1.21,
                'At': 1.21,
                'Ba': 2.15,
                'Bk': 1.54,
                'Be': 0.96,
                'Bi': 1.48,
                'Bh': 1.5,
                'B': 0.83,
                'Br': 1.21,
                'Cd': 1.54,
                'Cs': 2.44,
                'Ca': 1.76,
                'Cf': 1.83,
                'C': 0.68,
                'Ce': 2.04,
                'Cl': 0.99,
                'Cr': 1.39,
                'Co': 1.26,
                'Cu': 1.32,
                'Cm': 1.69,
                'Ds': 1.5,
                'Db': 1.5,
                'Dy': 1.92,
                'Es': 1.5,
                'Er': 1.89,
                'Eu': 1.98,
                'Fm': 1.5,
                'F': 0.64,
                'Fr': 2.6,
                'Gd': 1.96,
                'Ga': 1.22,
                'Ge': 1.17,
                'Au': 1.36,
                'Hf': 1.75,
                'Hs': 1.5,
                'He': 1.5,
                'Ho': 1.92,
                'H': 0.23,
                'In': 1.42,
                'I': 1.4,
                'Ir': 1.41,
                'Fe': 1.52,
                'Kr': 1.5,
                'La': 2.07,
                'Lr': 1.5,
                'Pb': 1.46,
                'Li': 1.28,
                'Lu': 1.87,
                'Mg': 1.41,
                'Mn': 1.61,
                'Mt': 1.5,
                'Md': 1.5,
                'Hg': 1.32,
                'Mo': 1.54,
                'Nd': 2.01,
                'Ne': 1.5,
                'Np': 1.9,
                'Ni': 1.24,
                'Nb': 1.64,
                'N': 0.68,
                'No': 1.5,
                'Os': 1.44,
                'O': 0.68,
                'Pd': 1.39,
                'P': 1.05,
                'Pt': 1.36,
                'Pu': 1.87,
                'Po': 1.4,
                'K': 2.03,
                'Pr': 2.03,
                'Pm': 1.99,
                'Pa': 2.0,
                'Ra': 2.21,
                'Rn': 1.5,
                'Re': 1.51,
                'Rh': 1.42,
                'Rb': 2.2,
                'Ru': 1.46,
                'Rf': 1.5,
                'Sm': 1.98,
                'Sc': 1.7,
                'Sg': 1.5,
                'Se': 1.22,
                'Si': 1.2,
                'Ag': 1.45,
                'Na': 1.66,
                'Sr': 1.95,
                'S': 1.02,
                'Ta': 1.7,
                'Tc': 1.47,
                'Te': 1.47,
                'Tb': 1.94,
                'Tl': 1.45,
                'Th': 2.06,
                'Tm': 1.9,
                'Sn': 1.39,
                'Ti': 1.6,
                'W': 1.62,
                'U': 1.96,
                'V': 1.53,
                'Xe': 1.5,
                'Yb': 1.87,
                'Y': 1.9,
                'Zn': 1.22,
                'Zr': 1.75
                }

vdWRADII = {
                'Ac': 2.0,
                'Al': 2.0,
                'Am': 2.0,
                'Sb': 2.0,
                'Ar': 1.88,
                'As': 1.85,
                'At': 2.0,
                'Ba': 2.0,
                'Bk': 2.0,
                'Be': 2.0,
                'Bi': 2.0,
                'Bh': 2.0,
                'B': 2.0,
                'Br': 1.85,
                'Cd': 1.58,
                'Cs': 2.0,
                'Ca': 2.0,
                'Cf': 2.0,
                'C': 1.7,
                'Ce': 2.0,
                'Cl': 1.75,
                'Cr': 2.0,
                'Co': 2.0,
                'Cu': 1.4,
                'Cm': 2.0,
                'Ds': 2.0,
                'Db': 2.0,
                'Dy': 2.0,
                'Es': 2.0,
                'Er': 2.0,
                'Eu': 2.0,
                'Fm': 2.0,
                'F': 1.47,
                'Fr': 2.0,
                'Gd': 2.0,
                'Ga': 1.87,
                'Ge': 2.0,
                'Au': 1.66,
                'Hf': 2.0,
                'Hs': 2.0,
                'He': 1.4,
                'Ho': 2.0,
                'H': 1.09,
                'In': 1.93,
                'I': 1.98,
                'Ir': 2.0,
                'Fe': 2.0,
                'Kr': 2.02,
                'La': 2.0,
                'Lr': 2.0,
                'Pb': 2.02,
                'Li': 1.82,
                'Lu': 2.0,
                'Mg': 1.73,
                'Mn': 2.0,
                'Mt': 2.0,
                'Md': 2.0,
                'Hg': 1.55,
                'Mo': 2.0,
                'Nd': 2.0,
                'Ne': 1.54,
                'Np': 2.0,
                'Ni': 1.63,
                'Nb': 2.0,
                'N': 1.55,
                'No': 2.0,
                'Os': 2.0,
                'O': 1.52,
                'Pd': 1.63,
                'P': 1.8,
                'Pt': 1.72,
                'Pu': 2.0,
                'Po': 2.0,
                'K': 2.75,
                'Pr': 2.0,
                'Pm': 2.0,
                'Pa': 2.0,
                'Ra': 2.0,
                'Rn': 2.0,
                'Re': 2.0,
                'Rh': 2.0,
                'Rb': 2.0,
                'Ru': 2.0,
                'Rf': 2.0,
                'Sm': 2.0,
                'Sc': 2.0,
                'Sg': 2.0,
                'Se': 1.9,
                'Si': 2.1,
                'Ag': 1.72,
                'Na': 2.27,
                'Sr': 2.0,
                'S': 1.8,
                'Ta': 2.0,
                'Tc': 2.0,
                'Te': 2.06,
                'Tb': 2.0,
                'Tl': 1.96,
                'Th': 2.0,
                'Tm': 2.0,
                'Sn': 2.17,
                'Ti': 2.0,
                'W': 2.0,
                'U': 1.86,
                'V': 2.0,
                'Xe': 2.16,
                'Yb': 2.0,
                'Y': 2.0,
                'Zn': 1.39,
                'Zr': 2.0
                }

METAL = {
    'Ac': True,  'Al': True,  'Am': True,  'Sb': True,  'Ar': False,
    'As': True,  'At': True,  'Ba': True,  'Bk': True,  'Be': True,
    'Bi': True,  'Bh': True,   'B': False,  'Br': False, 'Cd': True,
    'Cs': True,  'Ca': True,  'Cf': True,  'C': False,  'Ce': True,
    'Cl': False, 'Cr': True,  'Co': True,  'Cu': True,  'Cm': True,
    'Ds': True,  'Db': True,  'Dy': True,  'Es': True,  'Er': True,
    'Eu': True,  'Fm': True,  'F': False,  'Fr': True,  'Gd': True,
    'Ga': True,  'Ge': True,  'Au': True,  'Hf': True,  'Hs': True,
    'He': False, 'Ho': True,  'H': False,  'In': True,  'I': False,
    'Ir': True,  'Fe': True,  'Kr': False, 'La': True,  'Lr': True,
    'Pb': True,  'Li': True,  'Lu': True,  'Mg': True,  'Mn': True,
    'Mt': True,  'Md': True,  'Hg': True,  'Mo': True,  'Nd': True,
    'Ne': False, 'Np': True,  'Ni': True,  'Nb': True,  'N': False,
    'No': True,  'Os': True,  'O': False,  'Pd': True,  'P': False,
    'Pt': True,  'Pu': True,  'Po': True,  'K': True,   'Pr': True,
    'Pm': True,  'Pa': True,  'Ra': True,  'Rn': False, 'Re': True,
    'Rh': True,  'Rb': True,  'Ru': True,  'Rf': True,  'Sm': True,
    'Sc': True,  'Sg': True,  'Se': False, 'Si': True,  'Ag': True,
    'Na': True,  'Sr': True,  'S': False,  'Ta': True,  'Tc': True,
    'Te': True,  'Tb': True,  'Tl': True, 'Th': True,  'Tm': True,
    'Sn': True,  'Ti': True,  'W': True,  'U': True,  'V': True,
    'Xe': False, 'Yb': True,  'Y': True,  'Zn': True,  'Zr': True
}

ATR = {
        'H':0.38,
        'Li':0.86,
        'Be':0.53,
        'B':1.01,
        'C':0.88,
        'N':0.86,
        'O':0.89,
        'F':0.82,
        'Na':1.15,
        'Mg':1.28,
        'Al':1.53,
        'Si':1.38,
        'P':1.28,
        'S':1.20,
        'Cl':1.17,
        'K':1.44,
        'Ca':1.17,
        'Sc':1.62,
        'Ti':1.65,
        'V':1.51,
        'Cr':1.53,
        'Mn':1.53,
        'Fe':1.43,
        'Co':1.31,
        'Ni':1.33,
        'Cu':1.31,
        'Zn':1.41,
        'Ga':1.40,
        'Ge':1.35,
        'As':1.39,
        'Se':1.40,
        'Br':1.39,
        'Rb':1.65, 
        'Sr':1.30,
        'Y':1.84,
        'Zr':1.73,
        'Nb':1.66,
        'Mo':1.57,
        'Ru':1.58,
        'Rh':1.63,
        'Pd':1.68,
        'Ag':1.56,
        'Cd':1.56,
        'In':1.53,
        'Sn':1.64,
        'Sb':1.64,
        'Te':1.65,
        'I':1.58,
        'Cs':1.85,
        'Ba':1.52,
        'La':1.91,
        'Ce':1.98,
        'Pr':1.75,
        'Nd':1.92,
        'Sm':1.89,
        'Eu':1.83,
        'Gd':1.79,
        'Tb':1.82,
        'Dy':1.79,
        'Ho':1.63,
        'Er':1.80,
        'Tm':1.84,
        'Yb':1.80,
        'Lu':1.86,
        'Hf':1.73,
        'W':1.33,
        'Re':1.29,
        'Ir':1.50,
        'Pt':1.66,
        'Au':1.68,
        'Hg':1.88,
        'Pb':1.72,
        'Bi':1.72, 
        'Th':1.97,
        ' U':1.76,
        'Np':1.73,
        'Pu':1.71
        }


Coef_A = {
            'H':-0.6093,
            'B':-2.2011,
            'C':-1.2685,
            'N':-1.2680,
            'O':-1.0525,
            'Cl':-0.7621,
            'Br':-0.8003
        }


Coef_C = {
            'H':0.5927,
            'B':3.4380,
            'C':1.8855,
            'N':1.8401,
            'O':1.5189,
            'Cl':1.3723,
            'Br':1.5272
            }


BO_list = [
            'H',
            'B',
            'C',
            'N',
            'O',
            'Cl',
            'Br'
            ]


metals4check = [
                'Li',
                'Be',
                'Na',
                'Mg',
                'Al',
                'K',
                'Ca',
                'Sc',
                'Ti',
                'V',
                'Cr',
                'Mn',
                'Fe',
                'Co',
                'Ni',
                'Cu',
                'Zn',
                'Ga',
                'Rb',
                'Sr',
                'Y',
                'Zr',
                'Nb',
                'Mo',
                'Ru',
                'Rh',
                'Pd',
                'Ag',
                'Cd',
                'In',
                'Sn',
                'Cs',
                'Ba',
                'La',
                'Ce',
                'Pr',
                'Nd',
                'Sm',
                'Eu',
                'Gd',
                'Tb',
                'Dy',
                'Ho',
                'Er',
                'Tm',
                'Yb',
                'Lu',
                'Hf',
                'W',
                'Re',
                'Re',
                'Ir',
                'Pt',
                'Au',
                'Hg',
                'Pb',
                'Bi',
                'Th',
                'U',
                'Np',
                'Pu'
                ]

